@@ -48,7 +48,7 @@ class Slack(object):
     #
     # chat
     #
-    def post_message(self, channel, text, **kwargs):
+    def chat_post_message(self, channel, text, **kwargs):
         """Post a message to Slack."""
         return self.webclient.chat_postMessage(
             channel=channel,
